@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001, 2002, 2003, 2004 Philip Blundell <philb@gnu.org>
- * Hildon adaption by Florian Boor <florian.boor@kernelconcepts.de>
+ * Hildon adaption 2005 by Florian Boor <florian.boor@kernelconcepts.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -9,7 +9,7 @@
  */
 
 /*
- * $Id: main-hildon.c,v 1.1 2005/06/03 22:37:11 florian Exp $
+ * $Id: main-hildon.c,v 1.3 2005/07/25 15:17:11 florian Exp $
  *
  */
 
@@ -1443,7 +1443,7 @@ create_main (gboolean edit_structure)
 			       GTK_ORIENTATION_HORIZONTAL);
 
   /* toolbar */
-  gtk_box_pack_end (GTK_BOX (vbox1), toolbar, FALSE, FALSE, 0);
+  hildon_appview_set_toolbar(HILDON_APPVIEW(main_appview), GTK_TOOLBAR(toolbar));
   
   /* buttons left */
   w = gtk_image_new_from_file(ICON_PATH "/qgn_list_gene_unknown_file.png");
